Calculate hikes given various constraints
=======================

The Hike Calculator helps you find and plan hikes suitable for your
available time and energy. It lets you pick alternatives that include
various waypoints and provides total and cummulative miles.
